# WARNING - Generated by {fusen} from dev/flat_create_tables_sequences.Rmd: do not edit by hand # nolint: line_length_linter.

#' Ajouter une variable code_prelevement au dataframe
#'
#' @description Cette fonction ajoute une nouvelle variable `code_prelevement` 
#' au dataframe en utilisant une séquence PostgreSQL dynamique. La séquence est 
#' construite en fonction du paramètre `version` fourni.
#'
#' @param dataframe Un dataframe contenant les données sur lesquelles ajouter 
#' la variable `code_prelevement`.
#' @param version Une chaîne de caractères représentant la version de la 
#' séquence à utiliser.
#'
#' @return Un dataframe avec une nouvelle colonne `code_prelevement` contenant 
#' les valeurs de la séquence PostgreSQL.
#' 
#' @importFrom DBI dbGetQuery dbDisconnect
#' @importFrom dplyr mutate
#' @importFrom glue glue
#' @importFrom datalibaba connect_to_db
#' @export
#' @examples
#' # Crée un dataframe fictif avec les colonnes nécessaires pour l'exemple
#' dataframe <- data.frame(
#'   id_prelevement = 1:5,
#'   autre_colonne = sample(letters, 5)
#' )
#' # Définir une version pour l'exemple
#' version <- "v1"
#'
#' # Utiliser la fonction add_code_prelevement() avec la version souhaitée
#' dataframe <- add_code_prelevement(
#'   dataframe, version)
#'
add_code_prelevement <- function(dataframe, version) {
  # Établir une connexion à la base de données PostgreSQL
  connexion <- datalibaba::connect_to_db(db = "si_eau", user = "admin")
  
  # Créer la séquence correspondant à la table
  create_sequence <- glue::glue("CREATE SEQUENCE IF NOT EXISTS nitrates.nitrate_prelevement_{version}_code_prelevement_seq
      INCREMENT 1 START 1 MINVALUE 1 MAXVALUE 2147483647 CACHE 1;")
  
  # Exécuter le script dans la base de données
  DBI::dbExecute(connexion, create_sequence)  
  
  # Construire le nom de la séquence
  sequence_name <- glue::glue("nitrates.nitrate_prelevement_{version}_code_prelevement_seq")
  
  # Initialiser une liste pour stocker les valeurs de la séquence
  code_prelevements <- c()
  
  # Pour chaque ligne du dataframe, obtenir une valeur de la séquence
  for (i in 1:nrow(dataframe)) {
    query <- glue::glue("SELECT nextval(\'{sequence_name}\') AS code_prelevement")
    result <- DBI::dbGetQuery(connexion, query)
    code_prelevements <- c(code_prelevements, result$code_prelevement)
  }
  
  # Ajouter la nouvelle variable au dataframe
  dataframe <- dataframe |>
    dplyr::mutate(code_prelevement = code_prelevements)
  
  # Fermer la connexion à la base de données
  DBI::dbDisconnect(connexion)
  
  return(dataframe)
}

